@@ -9,9 +9,8 @@
 #   WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #   License for the specific language governing permissions and limitations
 #   under the License.
-#
-"""Discovery Module
 
+"""Discovery Module.
 
     TODO(zns): testing, refactoring, etc...  just using this to demonstrate
     functionality
@@ -20,36 +19,57 @@ Example usage:
 
     from satori import discovery
     discovery.run(address="foo.com")
-
-
 """
 
 from __future__ import print_function
 
+import ipaddress as ipaddress_module
 from novaclient.v1_1 import client
+from pythonwhois import shared
+import six
 
 from satori import dns
+from satori import utils
 
 
-def run(address, config):
+def run(address, config, interactive=False):
     """Run discovery and return results."""
     results = {}
-    ipaddress = dns.resolve_hostname(address)
-    results['domain'] = dns.domain_info(address)
+    if utils.is_valid_ip_address(address):
+        ipaddress = address
+    else:
+        ipaddress = dns.resolve_hostname(address)
+        #TODO(sam): Use ipaddress.ip_address.is_global
+        #                   "               .is_private
+        #                   "               .is_unspecified
+        #                   "               .is_multicast
+        #       To determine address "type"
+        if not ipaddress_module.ip_address(unicode(ipaddress)).is_loopback:
+            try:
+                results['domain'] = dns.domain_info(address)
+            except shared.WhoisException as exc:
+                results['domain'] = str(exc)
+
     results['address'] = ipaddress
 
+    results['host'] = host = {'type': 'Undetermined'}
     if config.username is not None:
         server = find_nova_host(ipaddress, config)
         if server:
-            host = {'type': 'Nova instance'}
-
+            host['type'] = 'Nova instance'
             host['uri'] = [l['href'] for l in server.links
                            if l['rel'] == 'self'][0]
             host['name'] = server.name
             host['id'] = server.id
-
             host['addresses'] = server.addresses
-            results['host'] = host
+    if config.system_info:
+        module_name = config.system_info.replace("-", "_")
+        if '.' not in module_name:
+            module_name = 'satori.sysinfo.%s' % module_name
+        system_info_module = utils.import_object(module_name)
+        result = system_info_module.get_systeminfo(ipaddress, config,
+                                                   interactive=interactive)
+        host['system_info'] = result
     return results
 
 
@@ -62,7 +82,7 @@ def find_nova_host(address, config):
                          region_name=config.region,
                          service_type="compute")
     for server in nova.servers.list():
-        for network_addresses in server.addresses.itervalues():
+        for network_addresses in six.itervalues(server.addresses):
             for ipaddress in network_addresses:
                 if ipaddress['addr'] == address:
                     return server
